@@ -1,3 +1,16 @@
+//! A commandline tool to search for searching through systems for suitable systems for your Squadron
+
+#![warn(
+    rust_2018_idioms,
+    unused,
+    rust_2021_compatibility,
+    nonstandard_style,
+    future_incompatible,
+    missing_copy_implementations,
+    missing_debug_implementations,
+    missing_docs
+)]
+
 use std::fs::File;
 use std::io;
 
@@ -30,18 +43,22 @@ fn main() -> Result<(), Error> {
     Ok(())
 }
 
-fn display_systems<T: System>(systems: Vec<T>) {
+fn display_systems<'a, T: System<'a>>(systems: Vec<T>) {
     for system in systems {
         println!("{}", system.name());
     }
 }
 
+/// General error type
 #[derive(ThisError, Debug)]
 pub enum Error {
+    /// Error from parsing arguments or similar
     #[error("argument error: {0:?}")]
     Cli(#[from] cli::Error),
+    /// Error from parsing edsm file
     #[error(transparent)]
     Parse(#[from] edsm::Error),
+    /// Error from reading edsm file
     #[error("failed to read edsm data file: {0:?}")]
     Read(#[from] io::Error),
 }
